// Created Oct 2012 by William Garrison, http://www.mobydisk.com
// - Change the last line to create a 2-hole or a 3-hole log
//
// PRINTING NOTES:
// The final length of the 3-slot object is 194mm.  This is 1mm longer
// than my reference Lincoln Log.  But since ABS shrinks about 1mm
// this winds up just right.  If you use PLA, you might need to
// lower the length constant by 1mm to compensate.  Alternatively,
// you can make the holeLength 1mm bigger which is looser but
// would allow more tolerance in shrinkage.
//
// 10% infill results in something I could break if I really wanted to,
// but is plenty strong enough for all practical building purposes.
//
// I print this with a raft because otherwise round objects tend to flatten
// out at the bottom. That is not strictly a problem here but would
// result in something not quite Lincoln Log ish.  You could try to
// rotate it to build the flat side down, but then the slots have no
// material under them so you might need full support.
// I haven't tried these things, so if it works let me know!

$fs = 0.5;
$fa = 0.5;

length = 117;          // Length of a 2-hole block
diameter = 17;         // Diameter, measured on the round part
flatDiameter = 17.7;   // Diameter, measured on the flattened part
flatWidth = 7.5;       // The width of the flattened part
endLength = 11;        // The distance from the end of the block to the cutout hole
holeLength = 18;       // The length of the cutout hole
holeDepth = 5;         // The depth of the cutout hole

module LincolnLog2Slots() 
{

	// Rotate 90 degrees so that the cut outs sections don't need support
	// -- The downside of this is that the flat side is not on the bottom so
	//    you probably need a raft to keep the curvature right.
	translate([0,0,diameter/2])
	rotate([90,0,0])
	difference()
	{
		union()
		{
			rotate([0,90,0]) cylinder(h=length, r=diameter/2, center=true);
			cube([length, flatWidth, flatDiameter], center=true); 
		}

		// One cutout hole
		translate([length/2 - endLength - holeLength,-diameter/2,-flatDiameter/2]) 
		cube([holeLength,diameter,holeDepth]);

		// Repeat 4 times
		mirror([0,0,1])
		translate([length/2 - endLength - holeLength,-diameter/2,-flatDiameter/2]) 
		cube([holeLength,diameter,holeDepth]);

		mirror([1,0,0])
		translate([length/2 - endLength - holeLength,-diameter/2,-flatDiameter/2]) 
		cube([holeLength,diameter,holeDepth]);

		mirror([0,0,1]) mirror([1,0,0])
		translate([length/2 - endLength - holeLength,-diameter/2,-flatDiameter/2]) 
		cube([holeLength,diameter,holeDepth]);
	}
}

module LincolnLog3Slots()
{
	// This is the spacing used to construct a longer log
	spacingX = length - endLength - holeLength - endLength;

	// Construct a 3-length log by combining two 2-length logs
	translate([-spacingX/2,0,0])
		LincolnLog2Slots();
	translate([spacingX/2,0,0])
		LincolnLog2Slots();
}

LincolnLog3Slots();
